@@ -1,6 +1,6 @@
 package App::Standby::Frontend;
 {
-  $App::Standby::Frontend::VERSION = '0.01';
+  $App::Standby::Frontend::VERSION = '0.02';
 }
 BEGIN {
   $App::Standby::Frontend::AUTHORITY = 'cpan:TEX';
@@ -96,7 +96,7 @@ sub _init_config {
     my $self = shift;
 
     my $Config = Config::Yak::->new({
-        'locations'     => [qw(standby-mgm.conf /etc/standby-mgm)],
+        'locations'     => [qw(conf/standby-mgm.conf /etc/standby-mgm)],
     });
 
     return $Config;
@@ -480,6 +480,9 @@ sub run {
     elsif ( $request->{'rm'} eq 'update_group_service' && $request->{'gs_id'} ) {
         return $self->_render_update_service($request);
     }
+    elsif ( $request->{'rm'} eq 'delete_group_service_ask' && $request->{'gs_id'} ) {
+        return $self->_render_delete_service_ask($request);
+    }
     elsif ( $request->{'rm'} eq 'delete_group_service' && $request->{'gs_id'} ) {
         return $self->_render_delete_service($request);
     }
@@ -753,6 +756,7 @@ sub _render_update_service {
     if(!$sth->execute($request->{'value'},$request->{'config_id'})) {
         $self->logger()->log( message => 'Failed to execute stmt w/ error: '.$sth->errstr, level => 'error', );
     }
+    $sth->finish();
 
     return [ 301, [ 'Location', '?rm=overview&group_id='.$request->{'group_id'} ], [] ];
 }
@@ -785,9 +789,14 @@ sub _render_delete_service {
         return [ 301, [ 'Location', '?rm=overview&group_id='.$request->{'group_id'}.'&msg=Invalid%20Key' ], [] ];
     }
 
-    my $sql = 'DELETE FROM group_services WHERE id = ? ORDER BY id LIMIT 1';
+    my $sql = 'DELETE FROM group_services WHERE id = ?';
     my $sth = $self->dbh()->prepare($sql);
-    $sth->execute($request->{'gs_id'});
+    if(!$sth) {
+      $self->logger()->log( message => 'Failed to prepare SQL '.$sql.' w/ error: '.$self->dbh()->errstr, level => 'error', );
+    }
+    if(!$sth->execute($request->{'gs_id'})) {
+      $self->logger()->log( message => 'Failed to execute stmt w/ error: '.$sth->errstr, level => 'error', );
+    }
     $sth->finish();
 
     return [ 301, [ 'Location', '?rm=overview&group_id='.$request->{'group_id'} ], [] ];
@@ -934,7 +943,7 @@ sub _render_delete_config {
         return [ 301, [ 'Location', '?rm=overview&group_id='.$request->{'group_id'}.'&msg=Invalid%20Key' ], [] ];
     }
 
-    my $sql = 'DELETE FROM config WHERE id = ? ORDER BY id LIMIT 1';
+    my $sql = 'DELETE FROM config WHERE id = ?';
     my $sth = $self->dbh()->prepare($sql);
     $sth->execute($request->{'config_id'});
     $sth->finish();
@@ -1240,9 +1249,14 @@ sub _render_delete_contact {
 
     return unless $request->{'contact_id'};
 
-    my $sql = 'DELETE FROM contacts WHERE id = ? ORDER BY id LIMIT 1';
+    my $sql = 'DELETE FROM contacts WHERE id = ?';
     my $sth = $self->dbh()->prepare($sql);
-    $sth->execute($request->{'contact_id'});
+    if(!$sth) {
+        $self->logger()->log( message => 'Failed to prepare statement from SQL '.$sql.' w/ error: '.$self->dbh()->errstr(), level => 'error', );
+    }
+    if(!$sth->execute($request->{'contact_id'})) {
+        $self->logger()->log( message => 'Failed to execute statement w/ error: '.$sth->errstr(), level => 'error', );
+    }
     $sth->finish();
 
     return [ 301, [ 'Location', '?rm=overview&group_id='.$request->{'group_id'} ], [] ];
@@ -1431,7 +1445,7 @@ sub _render_overview {
             'services' => $services_ref,
         },
         \$body,
-    );
+    ) or return [ 500, [ 'Content-Type', 'text/plain'], [$self->tt()->error()]];
     return [ 200, [ 'Content-Type', 'text/html'], [$body]];
 }
 
